@@ -4,7 +4,7 @@
 #' 
 #' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
 #' 
-#' @return The function returns a dissimilarity matrix of the size \code{n x n}, where \code{n} is the number of objects in the original dataset in the argument \code{data}.
+#' @return The function returns an object of class "dist".
 #' \cr
 #' 
 #' @details The Eskin similarity measure was proposed by Eskin et al. (2002) and examined by Boriah et al., (2008). It is constructed to assign
@@ -26,7 +26,6 @@
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{lin1}},
-#' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
 #' \code{\link[nomclust]{ve}},
@@ -56,10 +55,8 @@ eskin <- function(data) {
   
   # recoding everything to factors and then to numeric values
   indx <- sapply(data, is.factor)
-  data[!indx] <- sapply(data[!indx], function(x) as.factor(x))
-  data <- as.data.frame(unclass(data))
-  data <- sapply(data, function(x) as.numeric(x))
-  data <- as.data.frame(data)
+  data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
+  data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
   num_cat <- sapply(data, function(x) length(unique(x)))
   
@@ -81,5 +78,5 @@ eskin <- function(data) {
       eskin[j,i] <- eskin[i,j]
     }
   }
-  return(eskin)
+  return(as.dist(eskin))
 }
