@@ -4,7 +4,7 @@
 #' 
 #' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
 #' 
-#' @return The function returns a dissimilarity matrix of the size \code{n x n}, where \code{n} is the number of objects in the original dataset in the argument \code{data}.
+#' @return The function returns an object of class "dist".
 #' \cr
 #' 
 #' @details The Goodall 2 similarity measure was presented in (Boriah et al., 2008). It is a simple modification of the original Goodall measure (Goodall, 1966).                         
@@ -25,7 +25,6 @@
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{lin1}},
-#' \code{\link[nomclust]{morlini}}, 
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
 #' \code{\link[nomclust]{ve}},
@@ -56,10 +55,8 @@ good2 <- function(data) {
   
   # recoding everything to factors and then to numeric values
   indx <- sapply(data, is.factor)
-  data[!indx] <- sapply(data[!indx], function(x) as.factor(x))
-  data <- as.data.frame(unclass(data))
-  data <- sapply(data, function(x) as.numeric(x))
-  data <- as.data.frame(data)
+  data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
+  data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
   
   freq.abs <- freq.abs(data)
@@ -92,5 +89,5 @@ good2 <- function(data) {
       }
     }
   }
-  return(good2)
+  return(as.dist(good2))
 }
\ No newline at end of file
