@@ -5,7 +5,7 @@
 #'  
 #' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
 #'
-#' @return The function returns a dissimilarity matrix of the size \code{n x n}, where \code{n} is the number of objects in the original dataset in the argument \code{data}.
+#' @return The function returns an object of class "dist".
 #' \cr
 #'
 #' @details The IOF (Inverse Occurrence Frequency) measure was originally constructed for the text mining tasks,
@@ -28,7 +28,6 @@
 #' \code{\link[nomclust]{good4}},
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{lin1}},
-#' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
 #' \code{\link[nomclust]{ve}},
@@ -61,10 +60,8 @@ iof <- function(data) {
   
   # recoding everything to factors and then to numeric values
   indx <- sapply(data, is.factor)
-  data[!indx] <- sapply(data[!indx], function(x) as.factor(x))
-  data <- as.data.frame(unclass(data))
-  data <- sapply(data, function(x) as.numeric(x))
-  data <- as.data.frame(data)
+  data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
+  data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
   freq.abs <- freq.abs(data)
   
@@ -89,5 +86,5 @@ iof <- function(data) {
       iof[j,i] <- iof[i,j]
     }
   }
-  return(iof)
+  return(as.dist(iof))
 }
\ No newline at end of file
