@@ -4,7 +4,7 @@
 #' 
 #' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
 #' 
-#' @return The function returns a dissimilarity matrix of the size \code{n x n}, where \code{n} is the number of objects in the original dataset in the argument \code{data}.
+#' @return The function returns an object of class "dist".
 #' \cr
 #'
 #' @details The Lin measure was introduced by Lin (1998) and presented in (Boriah et al., 2008).
@@ -27,7 +27,6 @@
 #' \code{\link[nomclust]{good4}},
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin1}},
-#' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
 #' \code{\link[nomclust]{ve}},
@@ -61,10 +60,8 @@ lin <- function(data) {
   
   # recoding everything to factors and then to numeric values
   indx <- sapply(data, is.factor)
-  data[!indx] <- sapply(data[!indx], function(x) as.factor(x))
-  data <- as.data.frame(unclass(data))
-  data <- sapply(data, function(x) as.numeric(x))
-  data <- as.data.frame(data)
+  data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
+  data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
   
   freq.abs <- freq.abs(data)
@@ -98,5 +95,5 @@ lin <- function(data) {
     }
   }
   lin[lin == -Inf] <- max(lin) + 1
-  return(lin)
+  return(as.dist(lin))
 }
\ No newline at end of file
