@@ -4,7 +4,7 @@
 #'                                        
 #' @param data A \emph{data.frame} or a \emph{matrix} with cases in rows and variables in colums.
 #' 
-#' @return The function returns a dissimilarity matrix of the size \code{n x n}, where \code{n} is the number of objects in the original dataset in the argument \code{data}.
+#' @return The function returns an object of class "dist".
 #' \cr
 #'
 #' @details The Lin 1 similarity measure was introduced in (Boriah et al., 2008) as a modification of the original Lin measure (Lin, 1998). In has
@@ -33,7 +33,6 @@
 #' \code{\link[nomclust]{good4}},
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin}},
-#' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
 #' \code{\link[nomclust]{sm}},
 #' \code{\link[nomclust]{ve}},
@@ -65,10 +64,8 @@ lin1 <- function(data) {
   
   # recoding everything to factors and then to numeric values
   indx <- sapply(data, is.factor)
-  data[!indx] <- sapply(data[!indx], function(x) as.factor(x))
-  data <- as.data.frame(unclass(data))
-  data <- sapply(data, function(x) as.numeric(x))
-  data <- as.data.frame(data)
+  data[!indx] <- lapply(data[!indx], function(x) as.factor(x))
+  data <- as.data.frame(sapply(data, function(x) as.numeric(x)))
   
   
   abs.freq <- freq.abs(data)
@@ -110,5 +107,5 @@ lin1 <- function(data) {
     }
   }
   lin1[lin1 == -Inf] <- max(lin1) + 1
-  return(lin1)
+  return(as.dist(lin1))
 }
\ No newline at end of file
